@@ -12,7 +12,7 @@ from ..externals import simplejson as json
 from . import schema
 from .jsonutil import get_column
 from .search import Search
-
+from .uriutil import check_entry
 
 class Inspector(object):
     """ Database introspection interface.
@@ -63,7 +63,7 @@ class Inspector(object):
             self._auto = auto
         if tick is not None:
             self._tick = tick
-        
+
     def datatypes(self, pattern='*', fields_pattern=None):
         """ Discovers the datatypes and datafields of the database.
 
@@ -80,8 +80,10 @@ class Inspector(object):
             -------
             list : datatypes or datafields depending on the argument usage.
         """
+        self._intf._get_entry_point()
 
-        search_els = self._get_json('/REST/search/elements?format=json')
+        search_els = self._get_json('%s/search/elements?format=json' % 
+                                        self._intf._entry)
 
         if not fields_pattern and ('*' in pattern or '?' in pattern):       
             return get_column(search_els , 'ELEMENT_NAME', pattern)
@@ -96,9 +98,10 @@ class Inspector(object):
             return fields
 
     def _datafields(self, datatype, pattern='*', prepend_type=True):
+        self._intf._get_entry_point()
 
-        search_fds = self._get_json('/REST/search/elements/%s?format=json' \
-                                        % datatype
+        search_fds = self._get_json('%s/search/elements/%s?format=json'
+                                        % (self._intf._entry, datatype)
                                     )
 
         fields = get_column(search_fds, 'FIELD_ID', pattern)
@@ -149,9 +152,12 @@ class Inspector(object):
         """
         return self._resource_types('scan')
 
+
     def field_values(self, field_name):
         """ Look for the values a specific datafield takes in the database. 
         """
+        self._intf._get_entry_point()
+
         search_tbl = Search(field_name.split('/')[0], 
                             [field_name], self._intf
                             )
@@ -170,7 +176,10 @@ class Inspector(object):
             .. note::
                 Is equivalent to interface.select.projects().get()
         """
-        return get_column(self._get_json('/REST/projects'), 'ID')
+        self._intf._get_entry_point()
+
+        return get_column(self._get_json(
+                '%s/projects' % self._intf._entry), 'ID')
 
     def subject_values(self, project=None):
         """ Look for the values a the subject level in the database.
@@ -178,7 +187,9 @@ class Inspector(object):
             .. note::
                 Is equivalent to interface.select('//subjects').get()
         """
-        uri = '/REST/subjects?columns=ID'
+        self._intf._get_entry_point()
+
+        uri = '%s/subjects?columns=ID' % self._intf._entry
 
         if project is not None:
             uri += '&project=%s' % project
@@ -201,7 +212,9 @@ class Inspector(object):
             project: string
                 Optional. Restrict operation to a project.
         """
-        uri = '/REST/experiments?columns=ID'
+        self._intf._get_entry_point()
+
+        uri = '%s/experiments?columns=ID' % self._intf._entry
         if datatype is not None:
             uri += '&xsiType=%s' % datatype
         if project is not None:
@@ -302,12 +315,16 @@ class Inspector(object):
     rest_hierarchy = architecture
 
     def _sub_experiment_values(self, sub_exp, project, experiment_type):
+        self._intf._get_entry_point()
+
         values = []
 
         column = '%s/%ss/%s/id' % \
             (experiment_type.lower(), sub_exp, sub_exp)
         
-        sub_exps = '/REST/experiments?columns=ID,%s' % column
+        sub_exps = '%s/experiments?columns=ID,%s' % (self._intf._entry, 
+                                                     column
+                                                     )
 
         if project is not None:
             sub_exps += '&project=%s' % project
