@@ -72,7 +72,7 @@ class Interface(object):
                 downloaded files)
                 If no path is provided, a platform dependent temp dir is 
                 used.
-           config: string
+v           config: string
                Reads a config file in json to get the connection parameters.
                If a config file is specified, it will be used regardless of
                other parameters that might have been given.
@@ -98,10 +98,11 @@ class Interface(object):
             self._pwd = password
 
             self._cachedir = os.path.join(
-                cachedir, 
-                '%s@%s' % (self._user, 
-                           self._server.split('//')[1].replace('/', '.')
-                           )
+                cachedir, '%s@%s' % (
+                    self._user, 
+                    self._server.split('//')[1].replace(
+                        '/', '.').replace(':', '_')
+                    )
                 )
         
         self._callback = None
@@ -110,11 +111,13 @@ class Interface(object):
         self._memtimeout = 1.0
         self._mode = 'online'
         self._struct = {}
+        self._entry = None
 
         self._last_memtimeout = 1.0
         self._last_mode = 'online'
 
         self._jsession = 'authentication_by_credentials'
+        self._connect_extras = {}
         self._connect()
 
         self.inspect = Inspector(self)
@@ -127,20 +130,43 @@ class Interface(object):
             self.draw = PaintGraph(self)
 
         if self._interactive:
-            self._jsession = self._exec('/REST/JSESSION')
+            self._get_entry_point()
+            self._jsession = self._exec('%s/JSESSION' % self._entry)
             if is_xnat_error(self._jsession):
                 catch_error(self._jsession)
 
         self.inspect()
 
-    def _connect(self):
+    def _get_entry_point(self):
+        if self._entry is None:
+            # /REST for XNAT 1.4, /data if >=1.5
+            self._entry = '/REST'
+            try:
+                self._exec('/data/JSESSION', 'HEAD')
+                self._entry = '/data'
+            except:
+                pass
+            
+    def _connect(self, **kwargs):
         """ Sets up the connection with the XNAT server.
+
+            Parameters
+            ----------
+            kwargs: dict
+                Can be used to pass additional arguments to
+                the Http constructor. See the httplib2 documentation
+                for details. http://code.google.com/p/httplib2/
         """
 
+        if kwargs != {}:
+            self._connect_extras = kwargs
+        else:
+            kwargs = self._connect_extras
+        
         if DEBUG:   
             httplib2.debuglevel = 2
-        self._conn = httplib2.Http(HTCache(self._cachedir, self))
-        self._conn.add_credentials(self._user, self._pwd)
+        self._http = httplib2.Http(HTCache(self._cachedir, self), **kwargs)
+        self._http.add_credentials(self._user, self._pwd)
 
     def _exec(self, uri, method='GET', body=None, headers=None):
         """ A wrapper around a simple httplib2.request call that:
@@ -160,9 +186,12 @@ class Interface(object):
             headers: dict
                 Additional headers for the HTTP request.
         """
+
         if headers is None:
             headers = {}
 
+        self._get_entry_point()
+
         uri = join_uri(self._server, uri)
 
         # using session authentication
@@ -179,19 +208,19 @@ class Interface(object):
                 if DEBUG:
                     print 'send: GET CACHE %s' % uri
 
-                info, content = self._conn.cache.get(uri
+                info, content = self._http.cache.get(uri
                                                      ).split('\r\n\r\n', 1)
 
                 self._memcache[uri] = time.time()
                 response = None
             else:
-                response, content = self._conn.request(uri, method, 
+                response, content = self._http.request(uri, method, 
                                                        body, headers)
                 self._memcache[uri] = time.time()
 
         elif self._mode == 'offline' and method == 'GET':
 
-            cached_value = self._conn.cache.get(uri)
+            cached_value = self._http.cache.get(uri)
 
             if cached_value is not None:
                 if DEBUG:
@@ -200,17 +229,17 @@ class Interface(object):
                 response = None
             else:
                 try:
-                    self._conn.timeout = 10
+                    self._http.timeout = 10
 
-                    response, content = self._conn.request(uri, method, 
+                    response, content = self._http.request(uri, method, 
                                                            body, headers)
 
-                    self._conn.timeout = None
+                    self._http.timeout = None
                     self._memcache[uri] = time.time()
                 except Exception, e:
                     catch_error(e)
         else:
-            response, content = self._conn.request(uri, method, 
+            response, content = self._http.request(uri, method, 
                                                    body, headers)
 
         if DEBUG:
@@ -226,7 +255,7 @@ class Interface(object):
             self._jsession = response.get('set-cookie')[:44]
 
         if response is not None and response.get('status') == '404':
-            r,_ = self._conn.request(self._server)
+            r,_ = self._http.request(self._server)
 
             if self._server.rstrip('/') != r.get('content-location', 
                                                  self._server).rstrip('/'):
@@ -273,6 +302,31 @@ class Interface(object):
 
         return csv_to_json(content)
 
+    def _get_head(self, uri):
+        print 'GET HEAD'
+        _nocache = httplib2.Http()
+        _nocache.add_credentials(self._user, self._pwd)
+
+        rheaders = {'cookie':self._jsession}
+
+        try:
+            head = _nocache.request(
+                '%s%s' % (self._server, uri), 'HEAD', headers=rheaders)[0]
+        except:
+            time.sleep(1)
+            head = _nocache.request(
+                '%s%s' % (self._server, uri), 'HEAD', headers=rheaders)[0]
+
+        info = email.Message.Message()
+
+        for key, value in head.iteritems():
+            if key == 'content-disposition':
+                info['content-location'] = '%s%s' % (self._server, uri)
+            if key not in ['set-cookie']:
+                info[key] = value
+
+        return info
+
     def save_config(self, location):
         """ Saves current configuration - including password - in a file.
 
@@ -382,4 +436,3 @@ class Interface(object):
 #                                 )
 
 #         return CObject(uris, self)
-
