@@ -3,7 +3,8 @@ import re
 from . import schema
 from .search import Search
 from .resources import CObject, Project, Projects # imports used implicitly
-from .uriutil import inv_translate_uri
+from .uriutil import inv_translate_uri, check_entry
+# from .uriutil import uri_last
 from .errors import ProgrammingError
 
 DEBUG = False
@@ -236,7 +237,10 @@ class Select(object):
             ID: string
                 ID of the project.
         """
-        return globals()['Project']('/REST/projects/%s' % ID, self._intf)
+        self._intf._get_entry_point()
+
+        return globals()['Project'](
+            '%s/projects/%s' % (self._intf._entry, ID), self._intf)
 
     def projects(self, id_filter='*'):
         """ Returns the list of all visible projects for the server.
@@ -246,12 +250,19 @@ class Select(object):
             id_filter: string
                 Name pattern to filter the returned projects.
         """
-        return globals()['Projects']('/REST/projects', self._intf, id_filter)
+        self._intf._get_entry_point()
+
+        return globals()['Projects'](
+            '%s/projects' % self._intf._entry, self._intf, id_filter)
 
     def tag(self, name):
+        self._intf._get_entry_point()
+
         return self._intf.manage.tags.get(name).references()
 
     def tags(self):
+        self._intf._get_entry_point()
+
         return self._intf.manage.tags()
 
     def __repr__(self):
@@ -274,17 +285,20 @@ class Select(object):
                 that has to be returned. Use the method `where` on the 
                 `Search` object to trigger a search on the database.
         """
+        self._intf._get_entry_point()
+
         if datatype_or_path.startswith('/tag'):
             if len(datatype_or_path.split('/')) == 3:
                 return self.tag(datatype_or_path.split('/')[-1])
             else:
                 return self.tags()
 
-        if datatype_or_path  in ['/', '//', '/REST']:
+        if datatype_or_path  in ['/', '//', self._intf._entry]:
             return self
 
-        if datatype_or_path.startswith('/REST'):
-            datatype_or_path = datatype_or_path.split('/REST')[1]
+        if datatype_or_path.startswith(self._intf._entry):
+            datatype_or_path = datatype_or_path.split(
+                self._intf._entry, 1)[1]
 
         if datatype_or_path.startswith('/'):
             return_list = []
@@ -296,6 +310,12 @@ class Select(object):
 
                     pairs = zip(path.split('/')[1::2], path.split('/')[2::2])
 
+                    # # in case a level id has a / - allowed for files only
+                    # if len(path.split('/')[1:]) % 2 == 1 \
+                    #         and uri_last(path) not in schema.resources_types:
+                        
+                    #     pairs[-1] = (pairs[-1][0], uri_last(path))
+
                     obj = self
                     for resource, identifier in pairs:
 
