@@ -1,3 +1,4 @@
+from .uriutil import check_entry
 from .jsonutil import JsonTable
 
 class Users(object):
@@ -35,30 +36,40 @@ class Users(object):
     def __call__(self):
         """ Returns the list of all registered users on the server.
         """
-        return JsonTable(self._intf._get_json('/REST/users')
+        self._intf._get_entry_point()
+
+        return JsonTable(self._intf._get_json('%s/users' % self._intf._entry)
                          ).get('login', always_list=True)
 
     def firstname(self, login):
         """ Returns the firstname of the user.
         """
-        return JsonTable(self._intf._get_json('/REST/users')
+        self._intf._get_entry_point()
+
+        return JsonTable(self._intf._get_json('%s/users' % self._intf._entry)
                          ).where(login=login)['firstname']
 
     def lastname(self, login):
         """ Returns the lastname of the user.
         """
-        return JsonTable(self._intf._get_json('/REST/users')
+        self._intf._get_entry_point()
+
+        return JsonTable(self._intf._get_json('%s/users' % self._intf._entry)
                          ).where(login=login)['lastname']
 
     def id(self, login):
         """ Returns the id of the user.
         """
-        return JsonTable(self._intf._get_json('/REST/users')
+        self._intf._get_entry_point()
+
+        return JsonTable(self._intf._get_json('%s/users' % self._intf._entry)
                          ).where(login=login)['xdat_user_id']
 
     def email(self, login):
         """ Returns the email of the user.
         """
-        return JsonTable(self._intf._get_json('/REST/users')
+        self._intf._get_entry_point()
+
+        return JsonTable(self._intf._get_json('%s/users' % self._intf._entry)
                          ).where(login=login)['email']
 
