@@ -3,19 +3,20 @@ from ..pyxnat import Interface
 central = Interface('http://central.xnat.org', 'nosetests', 'nosetests')
 
 def test_users():
-    assert isinstance(central.users(), list)
+    assert isinstance(central.manage.users(), list)
 
 def test_user_firstname():
-    assert central.users.firstname('nosetests') == 'Yannick'
+    assert central.manage.users.firstname('nosetests') == 'Yannick'
 
 def test_user_lastname():
-    assert central.users.lastname('nosetests') == 'Schwartz'
+    assert central.manage.users.lastname('nosetests') == 'Schwartz'
 
 def test_user_email():
-    assert central.users.email('nosetests') == 'yannick.schwartz@gmail.com'
+    assert central.manage.users.email('nosetests') == \
+        'yannick.schwartz@gmail.com'
 
 def test_user_id():
-    assert central.users.id('nosetests') == '204'
+    assert central.manage.users.id('nosetests') == '204'
 
 def test_project_users():
     assert isinstance(central.select.project('nosetests').users(), list)
@@ -27,16 +28,20 @@ def test_project_members():
     assert isinstance(central.select.project('nosetests').members(), list)
 
 def test_project_collaborators():
-    assert isinstance(central.select.project('nosetests').collaborators(), list)
+    assert isinstance(central.select.project('nosetests').collaborators(), 
+                      list
+                      )
 
 def test_project_user_role():
-    assert central.select.project('nosetests').user_role('nosetests') == 'owner'
+    assert central.select.project('nosetests'
+                                  ).user_role('nosetests') == 'owner'
 
 def test_add_remove_user():
     central.select.project('nosetests').add_user('schwarty', 'collaborator')
     assert 'schwarty' in central.select.project('nosetests').collaborators()
     central.select.project('nosetests').remove_user('schwarty')
-    assert 'schwarty' not in central.select.project('nosetests').collaborators()
+    assert 'schwarty' not in central.select.project('nosetests'
+                                                    ).collaborators()
 
 def test_project_accessibility():
     assert central.select.project('nosetests').accessibility() in \
